@@ -1,5 +1,5 @@
 package API::Google::GCal;
-$API::Google::GCal::VERSION = '0.06';
+$API::Google::GCal::VERSION = '0.07';
 
 use parent 'API::Google';
 # use base 'API::Google';
@@ -69,12 +69,25 @@ sub busy_time_ranges {
       timeMin => $params->{dt_start},
       timeMax => $params->{dt_end},
       timeZone => $params->{timeZone},
-      items => [{ 'id' => $params->{calendar_id} }]
+      items => [{ 'id' => $params->{calendarId} }]
     });
 };
 
 
 
+
+sub events_list {
+   my ($self, $params) = @_;
+    $self->api_query({ 
+      method => 'get', 
+      route => $self->{api_base}.'/calendars/'.$params->{calendarId}.'/events',
+      user => $params->{user}
+    })->{items};
+};
+
+
+
+
 1;
 
 __END__
@@ -89,7 +102,7 @@ API::Google::GCal - Google Calendar API client
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -121,7 +134,7 @@ version 0.06
 
     my $freebusy_data = {
       user => $user,
-      calendar_id => $calendar_id,
+      calendarId => $calendar_id,
       dt_start => DateTime::Format::RFC3339->format_datetime($event_start),
       dt_end => DateTime::Format::RFC3339->format_datetime($event_end),
       timeZone => 'Europe/Moscow'
@@ -129,6 +142,8 @@ version 0.06
 
     $gapi->busy_time_ranges($freebusy_data);
 
+    $gapi->events_list($freebusy_data);
+
 =head2 get_calendars
 
 Get all calendars of particular Google account
@@ -145,6 +160,19 @@ Get calendar id by its name. Name = "summary" parameter
 
 Return List of time ranges during which this calendar should be regarded as busy. 
 
+=head2 events_list
+
+Return list of events in particular calendar
+
+L<https://developers.google.com/google-apps/calendar/v3/reference/events/list>
+
+Usage:
+
+$gapi->events_list({
+  calendarID => 'ooqfhagr1a91u1510ffdf7vfpk@group.calendar.google.com',
+  user => 'someuser@gmail.com'
+});
+
 =head1 AUTHOR
 
 Pavel Serikov <pavelsr@cpan.org>
